@@ -3,7 +3,7 @@ BEGIN {
   $NetPacket::Ethernet::AUTHORITY = 'cpan:yanick';
 }
 BEGIN {
-  $NetPacket::Ethernet::VERSION = '1.1.0';
+  $NetPacket::Ethernet::VERSION = '1.1.1';
 }
 # ABSTRACT: Assemble and disassemble ethernet packets.
 
@@ -13,28 +13,27 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 BEGIN {
     @ISA = qw(Exporter NetPacket);
 
-# Items to export into callers namespace by default
-# (move infrequently used names to @EXPORT_OK below)
+    @EXPORT = qw();
 
-    @EXPORT = qw(
-    );
+    my @eth_types = qw/ ETH_TYPE_IP        
+                        ETH_TYPE_ARP       
+                        ETH_TYPE_APPLETALK 
+                        ETH_TYPE_RARP      
+                        ETH_TYPE_SNMP      
+                        ETH_TYPE_IPv6      
+                        ETH_TYPE_PPP       
+                        ETH_TYPE_802_1Q    
+                        ETH_TYPE_IPX       
+                        ETH_TYPE_PPPOED    
+                        ETH_TYPE_PPPOES    /;
 
-# Other items we are prepared to export if requested
-
-    @EXPORT_OK = qw(eth_strip 
-		    ETH_TYPE_IP ETH_TYPE_ARP ETH_TYPE_APPLETALK
-		    ETH_TYPE_SNMP ETH_TYPE_IPv6 ETH_TYPE_PPP
-    );
-
-# Tags:
+    @EXPORT_OK = ( 'eth_strip', @eth_types ); 
 
     %EXPORT_TAGS = (
-    ALL         => [@EXPORT, @EXPORT_OK],
-    strip       => [qw(eth_strip)],
-    types       => [qw(ETH_TYPE_IP ETH_TYPE_ARP ETH_TYPE_APPLETALK
-		       ETH_TYPE_SNMP ETH_TYPE_IPv6 ETH_TYPE_PPP)],
-);
-
+        ALL         => [@EXPORT, @EXPORT_OK],
+        strip       => [qw(eth_strip)],
+        types       => \@eth_types,
+    );
 }
 
 #
@@ -130,7 +129,7 @@ NetPacket::Ethernet - Assemble and disassemble ethernet packets.
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 =head1 SYNOPSIS
 
